@@ -1,8 +1,8 @@
-from .data_slicing import *
+from .data_slicing import check_column_balance, feature_importance, find_slices
 
 
 __all__ = [
+    "check_column_balance",
     "feature_importance",
     "find_slices",
-    "check_column_balance",
 ]
